summaryrefslogtreecommitdiffstats
path: root/kttsd/kcmkttsmgr/addtalker.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-17 22:17:08 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-17 22:17:08 +0000
commitf138d74fe16092003b06f5bde9663841929cde7f (patch)
treee9c497a0e59bc7d34264ac9404740d2ea76f3de4 /kttsd/kcmkttsmgr/addtalker.h
parent3a3c4b256baee79bdcfe72c5e01b9ded9b525900 (diff)
downloadtdeaccessibility-f138d74fe16092003b06f5bde9663841929cde7f.tar.gz
tdeaccessibility-f138d74fe16092003b06f5bde9663841929cde7f.zip
TQt4 port kdeaccessibility
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeaccessibility@1237325 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kttsd/kcmkttsmgr/addtalker.h')
-rw-r--r--kttsd/kcmkttsmgr/addtalker.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kttsd/kcmkttsmgr/addtalker.h b/kttsd/kcmkttsmgr/addtalker.h
index 33b9ba8..0c3f703 100644
--- a/kttsd/kcmkttsmgr/addtalker.h
+++ b/kttsd/kcmkttsmgr/addtalker.h
@@ -25,7 +25,7 @@
#ifndef ADDTALKER_H
#define ADDTALKER_H
-// Qt includes.
+// TQt includes.
#include <tqmap.h>
#include "addtalkerwidget.h"
@@ -36,15 +36,16 @@ typedef TQMap<TQString,TQStringList> LangToSynthMap;
class AddTalker : public AddTalkerWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param synthToLangMap TQMap of supported language codes indexed by synthesizer.
* @param parent Inherited KDialog parameter.
* @param name Inherited KDialog parameter.
*/
- AddTalker(SynthToLangMap synthToLangMap, TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
+ AddTalker(SynthToLangMap synthToLangMap, TQWidget* tqparent = 0, const char* name = 0, WFlags fl = 0 );
/**
* Destructor.
@@ -36,15 +36,16 @@ typedef TQMap<TQString,TQStringList> LangToSynthMap;
* Constructor.
* @param synthToLangMap TQMap of supported language codes indexed by synthesizer.
- * @param parent Inherited KDialog parameter.
+ * @param tqparent Inherited KDialog parameter.
* @param name Inherited KDialog parameter.
*/